pyrestsdk.clientfactory package — PyRESTSDK documentation

# pyrestsdk.clientfactory package

## Module contents

Client Factories

class pyrestsdk.clientfactory.AbstractHTTPClientFactory(session: Session)

  Bases: `ABC`

  Abstract HTTP Client Factory Type

  abstract create_with_custom_middleware(middleware: B) → Session

    Applies the custom middleware chain to the HTTP Client

  abstract create_with_default_middleware(credential: C) → Session

    Applies the default middleware chain to the HTTP Client

  session: Session

class pyrestsdk.clientfactory.HTTPClientFactory(session: Session)

  Bases: `AbstractHTTPClientFactory`

  HTTP Client Factory

  create_with_custom_middleware(middleware: List[B]) → Session

    Applies the custom middleware chain to the HTTP Client

  create_with_default_middleware(credential: C) → Session

    Applies the default middleware chain to the HTTP Client